pub struct ReaderClient<T: ReaderTransport> { /* private fields */ }Expand description
Protocol client over a ReaderTransport.
Implementations
Sourceimpl<T: ReaderTransport> ReaderClient<T>
impl<T: ReaderTransport> ReaderClient<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consume this client and return the wrapped transport.
Sourcepub fn transport_mut(&mut self) -> &mut T
pub fn transport_mut(&mut self) -> &mut T
Return a mutable reference to the wrapped transport.
Sourcepub async fn write_frame(
&mut self,
data: &[u8],
) -> Result<(), ClientError<T::Error>>
pub async fn write_frame( &mut self, data: &[u8], ) -> Result<(), ClientError<T::Error>>
Write a pre-built host frame to the transport without reading a response.
Sourcepub async fn read_frame(&mut self) -> Result<ReaderFrame, ClientError<T::Error>>
pub async fn read_frame(&mut self) -> Result<ReaderFrame, ClientError<T::Error>>
Read and parse one reader-to-host frame without sending a request first.
Sourcepub async fn transact_frame(
&mut self,
request: &[u8],
) -> Result<ReaderFrame, ClientError<T::Error>>
pub async fn transact_frame( &mut self, request: &[u8], ) -> Result<ReaderFrame, ClientError<T::Error>>
Send one pre-built host frame and parse a single response frame.
Sourcepub async fn transact(
&mut self,
command: u8,
data: &[u8],
) -> Result<ReaderFrame, ClientError<T::Error>>
pub async fn transact( &mut self, command: u8, data: &[u8], ) -> Result<ReaderFrame, ClientError<T::Error>>
Build and send one command payload, then parse one validated response.